==> alliance-5.0-20020701.tar.gz: alliance-5.0/ctp/src/ctp_util.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/* ###--------------------------------------------------------------### */
/*																		*/
/* file		: ctp_util.h												*/
/* date		: Jun 15 1992												*/
/* version	: v100														*/
/* author	: Pirouz BAZARGAN SABET										*/
/* description	: This file contains declaration of global and external	*/
/*		  variables and, functions used in `ctp_util.c`					*/
/*																		*/
/* ###--------------------------------------------------------------### */
	
#define CTP_MXRDFN     30

  extern long               CTP_LINNUM;	/* file's line number		*/
  extern char               CTP_ERRFLG;	/* Error flag                   */
  extern char               CTP_CURFIL[];	/* current file name		*/

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/ctp/src/ctp_util.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/* ###--------------------------------------------------------------### */
/*																		*/
/* file		: ctp_util.h												*/
/* date		: Jun 15 1992												*/
/* version	: v100														*/
/* author	: Pirouz BAZARGAN SABET										*/
/* description	: This file contains declaration of global and external	*/
/*		  variables and, functions used in `ctp_util.c`					*/
/*																		*/
/* ###--------------------------------------------------------------### */
	
#define CTP_MXRDFN     30

  extern long               CTP_LINNUM;	/* file's line number		*/
  extern char               CTP_ERRFLG;	/* Error flag                   */
  extern char               CTP_CURFIL[];	/* current file name		*/
